@@ -1,3 +1,4 @@
+from .models.k8s import Cluster, Node
 from .models.region import Region
 from .models.pagination import Pagination
 from .models.functions import Container, Namespace, Function, Cron, Log
@@ -310,6 +311,61 @@ class RegistryClient(ClientAPI):
         return Image(**json.loads(self.request(f"/images/{image.id}", ClientAPI.Method.DELETE, data=image.dict())))
 
 
+class K8sClient(ClientAPI):
+
+    def __init__(self, region: Region = Region.FrPar):
+        super().__init__(name="k8s", version="v1", region=region)
+
+    # CLUSTERS
+
+    @validate_arguments
+    def list_clusters(
+        self,
+        name: str = None,
+        status: Cluster.Status = Cluster.Status.Unknown,
+        type: str = None,
+        pagination: Pagination = Pagination(),
+        ordering: Cluster.Ordering = Cluster.Ordering(),
+        application_id: str = None,
+        organization_id: str = None,
+        project_id: str = None
+    ): return [Cluster(**data) for data in json.loads(
+            self.request("/clusters", data={
+                "status": status.value,
+                "type": type,
+                "application_id": application_id,
+                "organization_id": organization_id,
+                "project_id": project_id,
+                "name": name
+            } | pagination.dict() | ordering.dict()))["clusters"]]
+
+    @validate_arguments
+    def download_kubeconfig(
+        self,
+        cluster_id: str
+    ): return Node(**json.loads(self.request(f"/clusters/{cluster_id}/kubeconfig", data={
+            "cluster_id": cluster_id
+        }))["content"])
+
+    # NODES
+
+    @validate_arguments
+    def list_nodes(
+        self,
+        cluster_id: str,
+        pool_id: str = None,
+        name: str = None,
+        status: Node.Status = Node.Status.Unknown,
+        pagination: Pagination = Pagination(),
+        ordering: Node.Ordering = Node.Ordering(),
+    ): return [Node(**data) for data in json.loads(
+            self.request(f"/clusters/{cluster_id}/nodes", data={
+                "status": status.value,
+                "name": name,
+                "pool_id": pool_id
+            } | pagination.dict() | ordering.dict()))["nodes"]]
+
+
 class ObjectStorageClient:
 
     def __init__(self, region: Region = Region.FrPar):
